ReadTheDocs Dropdown Theme for MkDocs
=====================================
~[http://img.shields.io/pypi/v/rtd-dropdown.svg](https://pypi.python.org/pypi/rtd-dropdown)

![Dropdown Demo](example.png)

